@@ -1,10 +1,8 @@
-import jsonschema
 import os.path
+
+import jsonschema
 from parameterized import parameterized
-import pytest
-from unittest import TestCase
-from samtranslator.yaml_helper import yaml_parse
-from samtranslator.validator.validator import SamTemplateValidator
+
 from tests.validator.test_validator import TestValidatorBase
 
 BASE_PATH = os.path.dirname(__file__)
@@ -13,7 +11,6 @@ OUTPUT_FOLDER = os.path.join(BASE_PATH, "output", "api")
 
 
 class TestValidatorApi(TestValidatorBase):
-
     # jsonschema 4.* is more restrictive than 3, so we need a separate check
     # See https://github.com/aws/serverless-application-model/issues/2426
     jsonschemaMajorVersion = int(jsonschema.__version__.split(".")[0])
